==> ejc-proequipmentp-impl-3.0.0-20220514.090802-105-sources.jar: com/ejianc/business/purchase/service/IChangePurchaseContractService.java <==
package com.ejianc.business.purchase.service;

import com.ejianc.business.purchase.vo.ChangePurchaseContractVO;
import com.ejianc.business.purchase.vo.PurchaseContractVO;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;
import com.ejianc.business.purchase.bean.ChangePurchaseContractEntity;

import java.util.Map;

/**
 * 购置合同-变更表
 * 
 * @author generator
 * 
 */
public interface IChangePurchaseContractService extends IBaseService<ChangePurchaseContractEntity> {

    ChangePurchaseContractVO queryDetailRecord(Long id);

    Boolean editChangeFlag(Long id);

    ChangePurchaseContractVO addConvertByConId(Long contractId, Long changeId);

    ChangePurchaseContractVO insertOrUpdate(ChangePurchaseContractVO saveorUpdateVO, Boolean isControl);

    ChangePurchaseContractVO queryDetail(Long id);

    CommonResponse<String> deleteById(Long changeBillId);

    Map<String, Object> queryChangeCompare(Long id);

    ChangePurchaseContractVO queryChangeRecord(Long contractId, Long changeId);

    CommonResponse<String> effectiveSaveWriteContract(Long changeBillId, String billTypeCode, Boolean commitState);

    ParamsCheckVO targetCostCtrl(ChangePurchaseContractVO changeContractVO);

    ParamsCheckVO viewTargetCostCtrlInfo(Long id);

    ParamsCheckVO checkParams(ChangePurchaseContractVO vo, ParamsCheckVO paramsCheckVO2);
    ParamsCheckVO checkParamsMny( ChangePurchaseContractVO vo);
}

==> ejc-proequipmentp-impl-3.0.0-20220609.103549-131-sources.jar: com/ejianc/business/purchase/service/IChangePurchaseContractService.java <==
package com.ejianc.business.purchase.service;

import com.ejianc.business.purchase.vo.ChangePurchaseContractVO;
import com.ejianc.business.purchase.vo.PurchaseContractVO;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;
import com.ejianc.business.purchase.bean.ChangePurchaseContractEntity;

import java.util.Map;

/**
 * 购置合同-变更表
 * 
 * @author generator
 * 
 */
public interface IChangePurchaseContractService extends IBaseService<ChangePurchaseContractEntity> {

    ChangePurchaseContractVO queryDetailRecord(Long id);

    Boolean editChangeFlag(Long id);

    ChangePurchaseContractVO addConvertByConId(Long contractId, Long changeId);

    ChangePurchaseContractVO insertOrUpdate(ChangePurchaseContractVO saveorUpdateVO, Boolean isControl);

    ChangePurchaseContractVO queryDetail(Long id);

    CommonResponse<String> deleteById(Long changeBillId);

    Map<String, Object> queryChangeCompare(Long id);

    ChangePurchaseContractVO queryChangeRecord(Long contractId, Long changeId);

    CommonResponse<String> effectiveSaveWriteContract(Long changeBillId, String billTypeCode, Boolean commitState);

    ParamsCheckVO targetCostCtrl(ChangePurchaseContractVO changeContractVO);

    ParamsCheckVO viewTargetCostCtrlInfo(Long id);

    ParamsCheckVO checkParams(ChangePurchaseContractVO vo, ParamsCheckVO paramsCheckVO2);
    ParamsCheckVO checkParamsMny( ChangePurchaseContractVO vo);
    /*施工合同 控 变更合同
     *        @param 变更合同vo vo

     * */
    ParamsCheckVO checkParamsConstruction(ChangePurchaseContractVO vo);
}
